document.addEventListener("DOMContentLoaded", function () {
    let apiKey = "";

    // 🔑 Получаем API-ключ
    function getApiKey() {
        return fetch('/wp-content/plugins/nowplaying-widget/nowplaying-api.php')
            .then(response => response.json())
            .then(data => {
                if (data.error) {
                    console.error("❌ Ошибка API:", data.error);
                    return Promise.reject("Неверный ключ");
                }
                console.log("🔑 Новый API-ключ получен:", data.api_key);
                apiKey = data.api_key;
            })
            .catch(error => console.error("❌ Ошибка получения API-ключа: ", error));
    }

    // 📡 Обновление данных виджета
    function updateNowPlaying() {
        if (!apiKey) {
            console.warn("⚠ API-ключ ещё не загружен, пропускаем обновление");
            return;
        }

        console.log("🔑 API-ключ для запроса: ", apiKey);

        fetch(`/wp-content/plugins/nowplaying-widget/nowplaying-api.php?key=${apiKey}`)
            .then(response => response.json())
            .then(data => {
                console.log("📡 Полученные данные:", data);
                if (!data.track || data.track === 'Нет данных') return;

                let trackElement = document.getElementById("nowplaying-track");
                let artworkElement = document.getElementById("nowplaying-artwork");
                let historyContainer = document.getElementById("nowplaying-history");

                if (trackElement) {
                    trackElement.textContent = data.track;
                }

                if (artworkElement) {
                    artworkElement.src = data.artwork + '?' + new Date().getTime();
                }

                if (historyContainer) {
                    historyContainer.innerHTML = "";
                    data.history.forEach((track, index) => {
                        let li = document.createElement("li");
                        li.classList.add("history-item");

                        let img = document.createElement("img");
                        img.src = data.thumbnails ? data.thumbnails[index] : "/wp-content/plugins/nowplaying-widget/data/placeholder.jpg";
                        img.alt = "Обложка";
                        img.classList.add("history-thumb");

                        let text = document.createElement("span");
                        text.textContent = track;

                        li.appendChild(img);
                        li.appendChild(text);
                        historyContainer.appendChild(li);
                    });
                }
            })
            .catch(error => console.error("❌ Ошибка загрузки данных: ", error));
    }

    // 🔍 Галерея (увеличение изображения при клике)
    function setupImagePopup() {
        const artwork = document.getElementById("nowplaying-artwork");

        // Создаём контейнер галереи
        const popup = document.createElement("div");
        popup.classList.add("image-popup");
        popup.innerHTML = `<span class="close-btn">&times;</span><img src="" alt="Обложка">`;
        document.body.appendChild(popup);

        const popupImage = popup.querySelector("img");
        const closeBtn = popup.querySelector(".close-btn");

        // Открытие увеличенного изображения
        artwork.addEventListener("click", function () {
            popupImage.src = artwork.src;
            popup.style.display = "flex";
        });

        // Закрытие по кнопке
        closeBtn.addEventListener("click", function () {
            popup.style.display = "none";
        });

        // Закрытие по клику вне изображения
        popup.addEventListener("click", function (e) {
            if (e.target === popup) {
                popup.style.display = "none";
            }
        });
    }

    // 🚀 Запуск процессов
    getApiKey().then(() => {
        updateNowPlaying();
        setInterval(updateNowPlaying, 5000);
        setupImagePopup();
    });
});
