<?php
/**
 * Страница настроек Now Playing
 */

if (!defined('ABSPATH')) {
    exit;
}

// Функция добавления страницы настроек в админку
function nowplaying_add_admin_menu() {
    add_menu_page(
        'Now Playing Settings',
        'Now Playing',
        'manage_options',
        'nowplaying-settings',
        'nowplaying_render_settings_page'
    );
}
add_action('admin_menu', 'nowplaying_add_admin_menu');

// Функция рендеринга страницы настроек
function nowplaying_render_settings_page() {
    $settings_file = plugin_dir_path(__FILE__) . '../data/settings.json';

    // Проверяем, существует ли файл настроек
    if (!file_exists($settings_file)) {
        file_put_contents($settings_file, json_encode(['api_key' => 'tyxCrkV6as']));
    }

    // Обработка формы
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['api_key'])) {
        $new_api_key = sanitize_text_field($_POST['api_key']);
        
        if (@file_put_contents($settings_file, json_encode(['api_key' => $new_api_key])) === false) {
            echo '<div class="error"><p>Ошибка: Не удалось сохранить API-ключ!</p></div>';
        } else {
            // Очистка кеша, чтобы API-ключ сразу обновился
            clearstatcache();
            echo '<div class="updated"><p>✅ API-ключ успешно обновлён!</p></div>';
        }
    }

    // Загружаем актуальный ключ
    $settings = json_decode(file_get_contents($settings_file), true);
    $current_key = esc_attr($settings['api_key'] ?? '');

    ?>
    <div class="wrap">
        <h1>🔧 Настройки Now Playing</h1>
        <form method="POST">
            <label for="api_key"><b>API-ключ:</b></label>
            <input type="text" name="api_key" id="api_key" value="<?php echo $current_key; ?>">
            <button type="submit" class="button button-primary">💾 Сохранить</button>
        </form>
    </div>
    <?php
}
?>
